@@ -1,13 +1,13 @@
 /* ctl_cyrusdb.c -- Program to perform operations common to all cyrus DBs
  *
- * Copyright (c) 1998-2003 Carnegie Mellon University.  All rights reserved.
+ * Copyright (c) 1994-2008 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -16,14 +16,15 @@
  *
  * 3. The name "Carnegie Mellon University" must not be used to
  *    endorse or promote products derived from this software without
- *    prior written permission. For permission or any other legal
- *    details, please contact  
- *      Office of Technology Transfer
+ *    prior written permission. For permission or any legal
+ *    details, please contact
  *      Carnegie Mellon University
- *      5000 Forbes Avenue
- *      Pittsburgh, PA  15213-3890
- *      (412) 268-4387, fax: (412) 268-7395
- *      tech-transfer@andrew.cmu.edu
+ *      Center for Technology Transfer and Enterprise Creation
+ *      4615 Forbes Avenue
+ *      Suite 302
+ *      Pittsburgh, PA  15213
+ *      (412) 268-7393, fax: (412) 268-7395
+ *      innovation@andrew.cmu.edu
  *
  * 4. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
@@ -38,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: ctl_cyrusdb.c,v 1.29 2007/03/30 18:40:20 murch Exp $
+ * $Id: ctl_cyrusdb.c,v 1.32 2008/03/24 17:09:16 murch Exp $
  */
 
 #include <config.h>
@@ -80,6 +81,7 @@
 #include "libcyr_cfg.h"
 #include "mboxlist.h"
 #include "seen.h"
+#include "statuscache.h"
 #include "tls.h"
 #include "util.h"
 #include "xmalloc.h"
@@ -99,7 +101,8 @@ struct cyrusdb {
     { FNAME_ANNOTATIONS,	&config_annotation_db,	1 },
     { FNAME_DELIVERDB,		&config_duplicate_db,	0 },
     { FNAME_TLSSESSIONS,	&config_tlscache_db,	0 },
-    { FNAME_PTSDB,              &config_ptscache_db,    0 },
+    { FNAME_PTSDB,		&config_ptscache_db,	0 },
+    { FNAME_STATUSCACHEDB,	&config_statuscache_db,	0 },
     { NULL,			NULL,			0 }
 };
 
@@ -160,10 +163,17 @@ void recover_reserved()
     annotatemore_init(0, NULL, NULL);
     annotatemore_open(NULL);
 
+    /* Need quotadb for deleting mailboxes with quotas */
+    quotadb_init(0);
+    quotadb_open(NULL);
+
     /* build a list of mailboxes - we're using internal names here */
     mboxlist_findall(NULL, pattern, 1, NULL,
 		     NULL, fixmbox, NULL);
 
+    quotadb_close();
+    quotadb_done();
+
     annotatemore_close();
     annotatemore_done();
 
