@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mbexamine.c,v 1.22 2009/08/28 13:53:25 brong Exp $
+ * $Id: mbexamine.c,v 1.24 2009/09/22 01:46:54 brong Exp $
  */
 
 #include <config.h>
@@ -218,6 +218,7 @@ int do_examine(char *name,
     struct mailbox mailbox;
     struct index_record record;
     cacherecord crec;
+    int j;
     
     signals_poll();
 
@@ -321,7 +322,6 @@ int do_examine(char *name,
 
     for(i=1; i<=mailbox.exists; i++) {
 	mailbox_read_index_record(&mailbox, i, &record);
-	int j;
 
 	if(wantvalue) {
 	    if(!wantuid) {
@@ -332,12 +332,10 @@ int do_examine(char *name,
 	    flag = 1;
 	}
 
-	printf("%06d> UID:%08ld   INT_DATE:" SIZE_T_FMT 
-               " SENTDATE: " SIZE_T_FMT " SIZE:%-6ld\n",
+	printf("%06d> UID:%08ld   INT_DATE:%ld SENTDATE:%ld SIZE:%-6ld\n",
 	       i, record.uid, record.internaldate,
 	       record.sentdate, record.size);
-	printf("      > HDRSIZE:%-6ld LASTUPD : " SIZE_T_FMT
-               " SYSFLAGS:%08X",
+	printf("      > HDRSIZE:%-6ld LASTUPD :%ld SYSFLAGS:%08X",
 	       record.header_size, record.last_updated,
 	       record.system_flags);
 	if (mailbox.minor_version >= 5)
@@ -416,6 +414,8 @@ int do_quota(char *name,
     struct mailbox mailbox;
     struct index_record record;
     uquota_t total = 0;
+    char fnamebuf[MAILBOX_FNAME_LEN];
+    struct stat sbuf;
     
     signals_poll();
 
@@ -450,8 +450,6 @@ int do_quota(char *name,
 
     for(i=1; i<=mailbox.exists; i++) {
 	mailbox_read_index_record(&mailbox, i, &record);
-	char fnamebuf[MAILBOX_FNAME_LEN];
-	struct stat sbuf;
 
 	strlcpy(fnamebuf, mailbox.path, sizeof(fnamebuf));
 	strlcat(fnamebuf, "/", sizeof(fnamebuf));
