@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: saslclient.c,v 1.18 2008/03/24 17:09:19 murch Exp $
+ * $Id: saslclient.c,v 1.19 2008/10/08 15:47:08 murch Exp $
  */
 
 #include <config.h>
@@ -252,7 +252,7 @@ int saslclient(sasl_conn_t *conn, struct sasl_cmd_t *sasl_cmd,
 
 	/* send to server */
 	if (sendliteral) {
-	    prot_printf(pout, "{%d+}\r\n", strlen(base64));
+	    prot_printf(pout, "{" SIZE_T_FMT "+}\r\n", strlen(base64));
 	    prot_flush(pout);
 	}
 	prot_printf(pout, "%s", base64);
