@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: seen_local.c,v 1.45 2008/03/24 17:09:19 murch Exp $
+ * $Id: seen_local.c,v 1.46 2009/03/31 04:11:20 brong Exp $
  */
 
 #include <config.h>
@@ -65,6 +65,7 @@
 #include "retry.h"
 #include "mailbox.h"
 #include "imap_err.h"
+#include "util.h"
 #include "xmalloc.h"
 
 #include "seen.h"
@@ -188,7 +189,7 @@ int seen_lockread(struct seen *seendb, time_t *lastreadptr, unsigned int *lastui
     left = length - namelen;
 
     /* Parse last-read timestamp */
-    while (left && isdigit((int) *buf)) {
+    while (left && Uisdigit(*buf)) {
 	*lastreadptr = *lastreadptr * 10 + *buf++ - '0';
 	left--;
     }
@@ -198,7 +199,7 @@ int seen_lockread(struct seen *seendb, time_t *lastreadptr, unsigned int *lastui
     }
 
     /* Parse last-read uid */
-    while (left && isdigit((int) *buf)) {
+    while (left && Uisdigit(*buf)) {
 	*lastuidptr = *lastuidptr * 10 + *buf++ - '0';
 	left--;
     }
@@ -209,12 +210,12 @@ int seen_lockread(struct seen *seendb, time_t *lastreadptr, unsigned int *lastui
 
     /* Scan for end of uids or last-change timestamp */
     p = buf;
-    while (left && !isspace((int) *p)) {
+    while (left && !Uisspace(*p)) {
 	p++;
 	left--;
     }
 
-    if (left > 1 && p[0] == ' ' && isdigit((int) p[1])) {
+    if (left > 1 && p[0] == ' ' && Uisdigit(p[1])) {
 	/* Have a last-change timestamp */
 	while (buf < p) {
 	    *lastchangeptr = *lastchangeptr * 10 + *buf++ - '0';
@@ -224,7 +225,7 @@ int seen_lockread(struct seen *seendb, time_t *lastreadptr, unsigned int *lastui
 	left--;
 
 	/* Scan for end of uids */
-	while (left && !isspace((int) *p)) {
+	while (left && !Uisspace(*p)) {
 	    p++;
 	    left--;
 	}
@@ -603,7 +604,7 @@ int seen_reconstruct(struct mailbox *mailbox,
 	/* Parse last-read timestamp */
 	p++;
 	lastread = 0;
-	while (p < endline && isdigit((int) *p)) {
+	while (p < endline && Uisdigit(*p)) {
 	    lastread = lastread * 10 + *p++ - '0';
 	}
 	if (p >= endline || *p++ != ' ') {
@@ -628,7 +629,7 @@ int seen_reconstruct(struct mailbox *mailbox,
 	
 	/* Parse last-read uid */
 	lastuidread = 0;
-	while (p < endline && isdigit((int) *p)) {
+	while (p < endline && Uisdigit(*p)) {
 	    lastuidread = lastuidread * 10 + *p++ - '0';
 	}
 	if (p >= endline || *p++ != ' ' || lastuidread > uidtoobig) {
@@ -643,9 +644,9 @@ int seen_reconstruct(struct mailbox *mailbox,
 	space = memchr(p, ' ', endline - p);
 
 	if (space && space+1 < endline &&
-	    space[0] == ' ' && isdigit((int) space[1])) {
+	    space[0] == ' ' && Uisdigit(space[1])) {
 	    /* Have a last-change timestamp */
-	    while (p < space && isdigit((int) *p)) {
+	    while (p < space && Uisdigit(*p)) {
 		lastchange = lastchange * 10 + *p++ - '0';
 	    }
 	    if (p != space) {
@@ -673,7 +674,7 @@ int seen_reconstruct(struct mailbox *mailbox,
 
 	while (p < space) {
 	    thisuid = 0;
-	    while (p < space && isdigit((int) *p)) {
+	    while (p < space && Uisdigit(*p)) {
 		if (dst) *dst++ = *p;
 		thisuid = thisuid * 10 + *p++ - '0';
 	    }
@@ -681,7 +682,7 @@ int seen_reconstruct(struct mailbox *mailbox,
 	    if (thisuid <= lastuid || thisuid > uidtoobig) {
 		/* Remove this UID and trailing separator */
 		FIXING();
-		while (isdigit((int) dst[-1])) dst--;
+		while (Uisdigit(dst[-1])) dst--;
 		if (dst[-1] == ':') dst[-1] = ',';
 	    }
 	    else if (lastsep == ':' && *p == ':') {
