@@ -40,7 +40,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: script.c,v 1.71 2009/11/19 21:52:56 murch Exp $
+ * $Id: script.c,v 1.71.2.1 2010/02/12 03:40:51 brong Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -232,6 +232,7 @@ static void add_header(sieve_interp_t *i, int isenv, char *header,
 		       int *outlen, int *outalloc)
 {
     const char **h;
+    char *decoded_header;
     int addlen;
     /* get header value */
     if (isenv)
@@ -242,7 +243,9 @@ static void add_header(sieve_interp_t *i, int isenv, char *header,
     if (!h || !h[0])
 	return;
 
-    addlen = strlen(h[0]) + 1;
+    decoded_header = charset_parse_mimeheader(h[0]);
+
+    addlen = strlen(decoded_header) + 1;
 
     /* realloc if necessary */
     if ( (*outlen) + addlen >= *outalloc)
@@ -252,13 +255,14 @@ static void add_header(sieve_interp_t *i, int isenv, char *header,
     }
 
     /* add header value */
-    strcat(*out,h[0]);
+    strcat(*out, decoded_header);
+
+    free(decoded_header);
 
     *outlen += addlen;
 }
 
 static int build_notify_message(sieve_interp_t *i,
-				struct hash_table *body_cache,
 				const char *msg, 
 				void *message_context, char **out, int *outlen)
 {
@@ -303,38 +307,9 @@ static int build_notify_message(sieve_interp_t *i,
 	    i->getbody(message_context, content_types, &parts);
 
 	    /* we only use the first text part */
-	    if (parts && parts[0]) {
-		const char *content = parts[0]->content;
-		int size = parts[0]->size;
-		int encoding;
-
-		/* XXX currently unknown encodings are processed as raw */
-		if (!parts[0]->encoding)
-		    encoding = ENCODING_NONE;
-		else if (!strcmp(parts[0]->encoding, "BASE64"))
-		    encoding = ENCODING_BASE64;
-		else if (!strcmp(parts[0]->encoding, "QUOTED-PRINTABLE"))
-		    encoding = ENCODING_QP;
-		else
-		    encoding = ENCODING_NONE;
-
-		if (encoding != ENCODING_NONE) {
-		    content = hash_lookup(parts[0]->section, body_cache);
-		    if (content) {
-			/* already decoded this part */
-			size = strlen(content);
-		    }
-		    else {
-			/* decode this part and add it to the cache */
-			char *decbuf = NULL;
-			content = charset_decode_mimebody(parts[0]->content,
-							  parts[0]->size,
-							  encoding, &decbuf,
-							  0, &size);
-			hash_insert(parts[0]->section, (void *) content,
-				    body_cache);
-		    }
-		}
+	    if (parts && parts[0] && parts[0]->decoded_body) {
+		const char *content = parts[0]->decoded_body;
+		int size = strlen(content);
 
 		if (n == 0 || n > (size_t)size) n = size;
 
@@ -428,7 +403,6 @@ static int sieve_removeflag(sieve_imapflags_t *imapflags, const char *flag)
 }
 
 static int send_notify_callback(sieve_interp_t *interp,
-				struct hash_table *body_cache,
 				void *message_context, 
 				void * script_context, notify_list_t *notify, 
 				char *actions_string, const char **errmsg)
@@ -449,7 +423,7 @@ static int send_notify_callback(sieve_interp_t *interp,
     nc.options = notify->options ? notify->options : NULL;
     nc.priority = notify->priority;
 
-    build_notify_message(interp, body_cache, notify->message, message_context, 
+    build_notify_message(interp, notify->message, message_context, 
 			 &out_msg, &out_msglen);
 
     build_msg = xmalloc(out_msglen + strlen(actions_string) + 30);
@@ -605,7 +579,6 @@ int sieve_script_unload(sieve_execute_t **s)
 
 static int do_sieve_error(int ret,
 			  sieve_interp_t *interp,
-			  struct hash_table *body_cache,
 			  void *script_context,
 			  void *message_context,
 			  sieve_imapflags_t * imapflags,
@@ -644,7 +617,7 @@ static int do_sieve_error(int ret,
 	    if (n->isactive) 
 	      {
 	      lastaction = ACTION_NOTIFY;
-	       notify_ret = send_notify_callback(interp, body_cache,
+	       notify_ret = send_notify_callback(interp,
 						 message_context, 
 						 script_context,n,
 						 actions_string, &errmsg);
@@ -658,7 +631,7 @@ static int do_sieve_error(int ret,
 	
 	
 	if (notify_ret != SIEVE_OK) 
-	  return do_sieve_error(ret, interp, body_cache,
+	  return do_sieve_error(ret, interp,
 				script_context, message_context,
 				imapflags, actions, notify_list, lastaction,
 				implicit_keep, actions_string, errmsg);
@@ -692,7 +665,7 @@ static int do_sieve_error(int ret,
 		     "Kept\n");
 	else {
 	    implicit_keep = 0;	/* don't try an implicit keep again */
-	    return do_sieve_error(ret, interp, body_cache,
+	    return do_sieve_error(ret, interp,
 				  script_context, message_context,
 				  imapflags, actions, notify_list, lastaction,
 				  implicit_keep, actions_string, errmsg);
@@ -707,7 +680,6 @@ static int do_sieve_error(int ret,
 
 
 static int do_action_list(sieve_interp_t *interp,
-			  struct hash_table *body_cache,
 			  void *script_context,
 			  void *message_context,
 			  sieve_imapflags_t *imapflags,
@@ -883,7 +855,7 @@ static int do_action_list(sieve_interp_t *interp,
 	}
     }
 
-    return do_sieve_error(ret, interp, body_cache,
+    return do_sieve_error(ret, interp,
 			  script_context, message_context, 
 			  imapflags, actions, notify_list, lastaction, 
 			  implicit_keep, actions_string, errmsg);
@@ -892,7 +864,7 @@ static int do_action_list(sieve_interp_t *interp,
 
 /* execute some bytecode */
 int sieve_eval_bc(sieve_execute_t *exe, int is_incl, sieve_interp_t *i,
-		  struct hash_table *body_cache, void *sc, void *m,
+		  void *sc, void *m,
 		  sieve_imapflags_t * imapflags, action_list_t *actions,
 		  notify_list_t *notify_list, const char **errmsg);
 
@@ -907,7 +879,6 @@ int sieve_execute_bytecode(sieve_execute_t *exe, sieve_interp_t *interp,
     char actions_string[ACTIONS_STRING_LEN] = "";
     const char *errmsg = NULL;
     sieve_imapflags_t imapflags;
-    struct hash_table body_cache;
     
     if (!interp) return SIEVE_FAIL;
 
@@ -917,42 +888,38 @@ int sieve_execute_bytecode(sieve_execute_t *exe, sieve_interp_t *interp,
     if (interp->notify) {
 	notify_list = new_notify_list();
 	if (notify_list == NULL) {
-	    return do_sieve_error(SIEVE_NOMEM, interp, NULL,
+	    return do_sieve_error(SIEVE_NOMEM, interp,
 				  script_context, message_context, &imapflags,
 				  actions, notify_list, lastaction, 0,
 				  actions_string, errmsg);
 	}
     }
 
-    /* build a hash table to cache decoded body parts */
-    construct_hash_table(&body_cache, 10, 1);
-    
     actions = new_action_list();
     if (actions == NULL) {
-	ret = do_sieve_error(SIEVE_NOMEM, interp, &body_cache,
+	ret = do_sieve_error(SIEVE_NOMEM, interp,
 			     script_context, message_context, &imapflags,
 			     actions, notify_list, lastaction, 0,
 			     actions_string, errmsg);
     }
     else {
-	ret = sieve_eval_bc(exe, 0, interp, &body_cache,
+	ret = sieve_eval_bc(exe, 0, interp,
 			    script_context, message_context,
 			    &imapflags, actions, notify_list, &errmsg);
 
 	if (ret < 0) {
-	    ret = do_sieve_error(SIEVE_RUN_ERROR, interp, &body_cache,
+	    ret = do_sieve_error(SIEVE_RUN_ERROR, interp,
 				 script_context, message_context, &imapflags,
 				 actions, notify_list, lastaction, 0,
 				 actions_string, errmsg);
 	}
 	else {
-	    ret = do_action_list(interp, &body_cache,
+	    ret = do_action_list(interp,
 				 script_context, message_context, 
 				 &imapflags, actions, notify_list,
 				 actions_string, errmsg);
 	}
     }
 
-    free_hash_table(&body_cache, free);
     return ret;
 }
